Mondrian art
============

Generate "modern art" using `Mondrian Processes <https://en.wikipedia.org/wiki/Piet_Mondrian#Paris_.281911.E2.80.931914.29>`__, from Python.

Installation
------------

It requires `Python 3 <https://docs.python.org/3/>`__, and can be
installed from `Pypi <https://pypi.python.org/pypi/mondrian-art/>`__
with `pip <https://pip.pypa.io/>`__:

.. code:: bash

    $ pip3 install mondrian-art


|PyPI download total| |PyPI download month| |PyPI download week| |PyPI download day|

|PyPI version| |PyPI format| |PyPI pyversions| |PyPI implementation| |PyPI status|

Usage
-----

From Python, use the fonction ``generate`` (with default options, or use
custom options, see the source for more information):

.. code:: python

    from mondrian_art import generate
    plt = generate()
    plt.show()


You can also execute the `mondrian_art.py <https://github.com/MechCoder/mondrian-art/blob/master/mondrian_art/mondrian_art.py>`__ script:

.. code:: bash

    $ python3 mondrian_art/mondrian_art.py


Sample images
-------------

|Image 1| |Image 2|

About
-----

Reference
~~~~~~~~~

Section 1 in `arXiv:1507.05181 <https://arxiv.org/pdf/1507.05181.pdf>`__.

Contributors |GitHub contributors|
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

1. `Manoj Kumar (MechCoder) <https://github.com/MechCoder/>`__
2. `Lilian Besson (Naereen) <https://github.com/Naereen/>`__

|Maintenance| |made-with-python|

License |PyPI license|
~~~~~~~~~~~~~~~~~~~~~~

`BSD 3 <https://github.com/MechCoder/mondrian-art/blob/master/LICENSE.txt>`__


.. |PyPI download total| image:: https://img.shields.io/pypi/dt/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI download month| image:: https://img.shields.io/pypi/dm/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI download week| image:: https://img.shields.io/pypi/dw/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI download day| image:: https://img.shields.io/pypi/dd/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI version| image:: https://badge.fury.io/py/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI format| image:: https://img.shields.io/pypi/format/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI pyversions| image:: https://img.shields.io/pypi/pyversions/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI implementation| image:: https://img.shields.io/pypi/implementation/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |PyPI status| image:: https://img.shields.io/pypi/status/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |GitHub contributors| image:: https://img.shields.io/github/contributors/MechCoder/mondrian-art.svg
   :target: https://GitHub.com/MechCoder/mondrian-art/graphs/contributors/
.. |Maintenance| image:: https://img.shields.io/badge/Maintained%3F-yes-green.svg
   :target: https://GitHub.com/MechCoder/mondrian-art/graphs/commit-activity
.. |made-with-python| image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/
.. |PyPI license| image:: https://img.shields.io/pypi/l/mondrian-art.svg
   :target: https://pypi.python.org/pypi/mondrian-art/
.. |Image 1| image:: https://github.com/MechCoder/mondrian-art/raw/master/images/image1.png
   :target: https://github.com/MechCoder/mondrian-art/blob/master/images/image1.png
.. |Image 2| image:: https://github.com/MechCoder/mondrian-art/raw/master/images/image2.png
   :target: https://github.com/MechCoder/mondrian-art/blob/master/images/image2.png
